The first maximum is taken over the August 1961 to April 1962 period, and the last maximum is taken over the August 2010 to April 2011 period. The object heatdata contains the core of the data:
vals: A \(50*90\) matrix containing the \(50\) summer maxima at the \(90\) locations.
sitesLL: A \(90*2\) matrix containing the sites locations in Latitude-Longitude, recentred (means have been substracted).
sitesEN: A \(90*2\) matrix containing the sites locations in Eastings-Northings, recentred (means have been substracted).
vals: A \(50*90\) matrix containing integers indicating the ``heatwave'' number of each of the \(50\) summer maxima at all \(90\) locations. Locations on the same row with the same integer indicates that they were obtained from the same heatwave. Heatwaves are defined over a three day window.
sitesLLO: A \(90*2\) matrix containing the sites locations in Latitude-Longitude, on the original scale.
sitesENO: A \(90*2\) matrix containing the sites locations in Eastings-Northings, on the original scale.
ufvals: A \(50*90\) matrix containing the \(50\) summer maxima at the \(90\) locations, on the unit Frechet scale.
Standardisation to unit Frechet is performed as in Beranger et al. (2021) by fitting the GEV distribution marginally using unconstrained location and shape parameters and the shape parameter to be a linear function of eastings and northings in 100 kilometre units. The resulting estimates are given in the objects locgrid, scalegrid and shapegrid, which are \(10*9\) matrices.
Details about the study region are given in geogmel, mellat and mellon. geogmel is a large SpatialPolygonsDataFrame of class s4 that was obtained using the sp package. mellat and mellon are vectors of length \(10\) and \(11\) which give the latitude and longitude coordinates of the grid.